@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "2.30.0"
+version     = "2.30.1"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/home/wwalker/git.gnome.org/orca/bld"
+prefix      = "/export/home/jd/orca/bld"
 
 # The package name (should be "orca").
 #
@@ -44,4 +44,4 @@ datadirname = "share"
 
 # The directory where we could find liblouis translation tables.
 #
-tablesdir = "/usr/share/liblouis/tables"
+tablesdir = ""
